import gtk,  os,  time
import mimetypes
mimetypes.init()



class FileManagerThing():
    """ From LXF 153, this is a simple filemanager that demonstrates uimanager"""
    def __init__(self):
        #initialise stuff
        #create liststore to store data for TreeView
        self.ui = '''<ui>
    <menubar name="MenuBar">
      <menu action="File">
        <menuitem action="Open"/>
        <menuitem action="Save"/>
        <menuitem action="Quit"/>
      </menu>
    </menubar>
    <toolbar name="Toolbar">
      <toolitem action="Open"/>
      <toolitem action="Save"/>
      <separator/>
      <toolitem action="Quit"/>
    </toolbar>
    </ui>'''
        self.ui_display = '''<ui>
        <menubar name="MenuBar">
            <menu action="Image">
                <menuitem action="Display"/>
            </menu>
        </menubar>
        <toolbar name="Toolbar">
            <separator/>
            <toolitem action="Display"/>
        </toolbar>
        </ui>
            '''
        self.liststore=gtk.ListStore(str, str, str,str)
        self.window=gtk.Window()
        self.uimanager = gtk.UIManager()
        self.accelgroup = self.uimanager.get_accel_group()
        self.window.add_accel_group(self.accelgroup)
        self.actiongroup = gtk.ActionGroup('global')
        # Create actions
        self.actiongroup.add_actions([
                    ('File', None, '_File'), 
                    ('Quit', gtk.STOCK_QUIT,  None,  '<Control>Q',None, self.on_quit_action), 
                    ('Open',  gtk.STOCK_OPEN,  None,  '<Control>O', None, self.on_open_action), 
                    ('Save',  gtk.STOCK_SAVE,  None,  '<Control>S', None,  self.on_save_action )
                         ] )             
      
        self.uimanager.insert_action_group(self.actiongroup, 0)
        self.uimanager.add_ui_from_string(self.ui)
        
        self.display_id=False
        self.actiongroup_display = gtk.ActionGroup('display')
        self.actiongroup_display.add_actions([
                    ('Image',  None,  '_Image'), 
                    ('Display',gtk.STOCK_MEDIA_PLAY, None, None, None,  self.on_display_action)
                    ])
        self.uimanager.insert_action_group(self.actiongroup_display, 0)
        #self.uimanager.add_ui_from_string(self.ui_display)       
        menubar = self.uimanager.get_widget('/MenuBar')
        toolbar = self.uimanager.get_widget('/Toolbar')
        #self.actiongroup_display.set_visible(False)
        #self.actiongroup_display.set_sensitive(False)
    # get directory to list
        self.dir=self.choose_dir()
        self.scan_dir(self.dir)
    #Create the TreeView
        self.treeview=gtk.TreeView(self.liststore)
        self.txtrenderer=gtk.CellRendererText()
        #set up columns for TreeView
        column = gtk.TreeViewColumn('Filename', self.txtrenderer,text=1)
        self.treeview.append_column(column)
        column = gtk.TreeViewColumn('type', self.txtrenderer,text=2)
        self.treeview.append_column(column)
        column = gtk.TreeViewColumn('Date modified', self.txtrenderer,text=3)
        self.treeview.append_column(column)
        self.treeview.columns_autosize()
        #put the widget in a scroll window just in case it geta too big
        scroll_window= gtk.ScrolledWindow()
        scroll_window.add(self.treeview)
        #set up signals
        self.treeview.set_reorderable(True)
        self.treeview.connect("row-activated", self.tree_doubleclick)
        


        #create a container for the main window and pack the menu and panes into it
        vbox = gtk.VBox(False, 2)
        vbox.pack_start(menubar, False, False, 0)
        vbox.pack_start(toolbar, False, False, 0)
        vbox.pack_start(scroll_window, True, True, 0)


        #set up window

        self.window.set_title("Evil Music Thing")
        self.window.set_size_request(800, 400)
        self.window.add(vbox)
        self.window.connect("destroy", gtk.main_quit)
        self.window.show_all()


# TODO: You need to fill in these actions yourself!
    def on_quit_action(self, item):
        self.window.destroy()
        gtk.main_quit()
        
    def on_open_action(self, item):
        x=self.choose_dir()
        self.scan_dir(x)
        
    def on_save_action(self, item):
        self.window.destroy()
        gtk.main_quit()
        
    def on_display_action(self, item):
        self.window.destroy()
        gtk.main_quit()


    def choose_dir(self):
        """Get user selection of  directory"""
        #thow up a file requestor to get a directory
        #then process it into list

        #generate file dialog
        x=gtk.FileChooserDialog(title="Source directory for files...", \
                        action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER, \
                        buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,\
                        gtk.STOCK_OK, gtk.RESPONSE_OK))
        #get the response
        response=x.run()
        path = ''
        if response == gtk.RESPONSE_OK:
           path = x.get_filename()
        x.destroy()
        return path

    def scan_dir(self, dir):
        """Scan given directory for  files and add them to the tree"""
        self.liststore.clear()
        if (dir == ''):
            return
        else:
            filelist=os.listdir(dir)
            #NB - you will need to add some more code here if you want to recurse into subdirectories
            filelist.sort()
            #iterate through filelist to generate
            for name in filelist:
                filepath=os.path.join(dir, name)
                #check it is a file
                if os.path.isfile(filepath):
                    # get mimetype
                    #get date
                    mtype=mimetypes.guess_type(filepath)
                    date=os.path.getmtime(filepath)
                    date=time.ctime(date)
                    
                    self.liststore.append([filepath, name, mtype[0],date])
        return




    def tree_doubleclick(self, tree,  path,  column):
        # path conatins the index of the selection
        #we can use this to fetch the data directly from the liststore object
        url = self.liststore[path[0]][0]
        mime= self.liststore[path[0]][2]
        #toggle the uimanager
        if (mime=='image/jpeg') :
            self.display_id = self.uimanager.add_ui_from_string(self.ui_display)  
        elif(self.display_id):
            self.uimanager.remove_ui(self.display_id)





        
def main():
    gtk.main()

if __name__ == "__main__":
    FileManagerThing()
    main()
