package com.example.mymap;

import android.content.Context;
import android.location.Address;
import android.location.Geocoder;
import android.view.MotionEvent;
import android.widget.Toast;
import android.util.Log;
import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;
import java.io.IOException;
import java.util.List;


public class FindLocationOverlay extends Overlay {
  private Context context;
  private final String TAG = "FindLocationOverlay";

  public FindLocationOverlay(Context c) {
    super();
    context = c;
  }

  @Override
  public boolean onTouchEvent(MotionEvent event, MapView mapView) {
    long duration = event.getEventTime() - event.getDownTime();
    if ( (event.getAction() == MotionEvent.ACTION_UP) && (duration > 1000)) {                
      GeoPoint p = mapView.getProjection().fromPixels(
                   (int) event.getX(),
                   (int) event.getY());
      double lat = p.getLatitudeE6() / 1E6;
      double lng = p.getLongitudeE6() / 1E6;
      Geocoder gc = new Geocoder(context);
      String addressString = "";
      try {
        List<Address> address = gc.getFromLocation(lat, lng, 1);
        if ((address!= null) && (address.size() > 0 )) {
          addressString = address.get(0).getThoroughfare() + ", " +
                          address.get(0).getLocality() + ", " +
                          address.get(0).getPostalCode();
        }
      } catch (IOException e) {
        e.printStackTrace();
      }
      Toast.makeText(context, 
                     "Lat/Long is: " + p.getLatitudeE6() / 1E6 + "," + 
                     p.getLongitudeE6() /1E6 + "\n" +
                     "Address is: " + addressString,
                     Toast.LENGTH_SHORT).show();
    }                            
    return false;
  }   
}


