package com.example.mymap;

import android.app.Activity;
import android.content.Context;
import android.graphics.drawable.Drawable;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.util.Log;
import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;
import com.google.android.maps.OverlayItem;
import java.io.IOException;
import java.util.List;

public class MyMap extends MapActivity
{
  private MapController mapController;
  protected MapView mapView;
  private CustomLocationOverlay myLocOverlay;
  private FindLocationOverlay findOverlay;
  private Geocoder geocoder;
  private String TAG = "MyMap";
  private static final int MICRO = 1000000;

  /** Called when the activity is first created. */
  @Override
  public void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.main);
    mapView = (MapView) findViewById(R.id.mapView);
    mapView.setBuiltInZoomControls(true);
    mapController = mapView.getController();
    myLocOverlay = new CustomLocationOverlay(this, mapView);
    findOverlay = new FindLocationOverlay(this);
    mapView.getOverlays().add(findOverlay);
    mapView.getOverlays().add(myLocOverlay);
    mapView.postInvalidate();
    setupGeocode();
  }

  @Override
  protected boolean isRouteDisplayed() {
    return false;
  }

  @Override
  protected void onResume() {
    super.onResume();
    myLocOverlay.enableMyLocation();
  }

  @Override
  protected void onPause() {
    super.onPause();
    myLocOverlay.disableMyLocation();
  }

  private void setupGeocode() {
    Button geoButton = (Button) findViewById(R.id.geoButton);
    geocoder = new Geocoder(this);
    geoButton.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        try {
          EditText addressBox = (EditText) findViewById(R.id.address);
          InputMethodManager imm = (InputMethodManager)
              getSystemService(Context.INPUT_METHOD_SERVICE);
          imm.hideSoftInputFromWindow(addressBox.getWindowToken(), 0);
          String address = addressBox.getText().toString();
          List<Address> addressList = geocoder.getFromLocationName(address, 1);
          if ((addressList != null) && (addressList.size() > 0 )) {
              gotoLocation(addressList.get(0));
          }
        } catch (IOException e) {
          e.printStackTrace();
        }
      } 
    });
  }


  /* This method gets the current location manually, instead of using the
   * MyLocationOverlay class */
  /*
  private void getCurrentLocation() {
    if (lm == null) {
      lm = (LocationManager) this.getSystemService(Context.LOCATION_SERVICE);
    }
    String locProvider = LocationManager.GPS_PROVIDER;

    Location l = lm.getLastKnownLocation(locProvider);
    if (l != null) gotoLocation(l);

    // Define a listener that responds to location updates
    LocationListener locListener = new LocationListener() {
      public void onLocationChanged(Location location) {
         gotoLocation(location);
         lm.removeUpdates(this);
      }

      public void onStatusChanged(String provider, int status, 
                                  Bundle extras) {}

      public void onProviderEnabled(String provider) {}

      public void onProviderDisabled(String provider) {}
    };

    lm.requestLocationUpdates(locProvider, 0, 0, locListener);
  }*/

  private void gotoLocation(Location loc) {
    int lat = (int) (loc.getLatitude() * MICRO);
    int lng = (int) (loc.getLongitude() * MICRO);
    gotoLocation(lat, lng);
   }

  private void gotoLocation(Address address) {
    int lat = (int) (address.getLatitude() * MICRO);
    int lng = (int) (address.getLongitude() * MICRO);
    gotoLocation(lat, lng);
  }

  private void gotoLocation(int lat, int lng) {
    GeoPoint gp = new GeoPoint(lat, lng);
    mapController.setCenter(gp);
    mapController.setZoom(15);
    showLocationOnMap(gp); 
  }

  private void showLocationOnMap(GeoPoint gp) {
    List<Overlay> mapOverlays = mapView.getOverlays();
    Drawable pin = this.getResources().getDrawable(R.drawable.pin);
    ShowLocationOverlay pinOverlay = new ShowLocationOverlay(pin);
    OverlayItem item = new OverlayItem(gp, "Address", "here");
    pinOverlay.addOverlay(item);
    mapOverlays.add(pinOverlay);
  }
}
